Package: FRAPO
Version: 0.4-2
Date: 2026-01-24
Title: Financial Risk Modelling and Portfolio Optimisation with R
Authors@R: c(person("Bernhard", "Pfaff", email = "bernhard@pfaffikus.de", role = c("aut", "cre")))
Depends: R (>= 3.1.3), methods, cccp, Rglpk, timeSeries
Description: Accompanying package of the book 'Financial Risk Modelling
        and Portfolio Optimisation with R', second edition. The data sets used in the book are contained in this package.
LazyData: TRUE
License: GPL (>= 3)
NeedsCompilation: no
Author: Bernhard Pfaff [aut, cre]
Maintainer: Bernhard Pfaff <bernhard@pfaffikus.de>
Packaged: 2026-01-24 16:37:10 UTC; bp
Repository: CRAN
Date/Publication: 2026-01-25 06:10:37 UTC
Built: R 4.6.0; ; 2026-04-25 19:03:11 UTC; unix
