## Installation of the book's accompanying package
install.packages("FRAPO")
## Loading of the package
library(FRAPO)
## Overview of the help topics
help(package = FRAPO)
## Displaying help for the examples
?BookEx
## Showing the listing of R code examples
listEx()
## Returning the content of this example
showEx("C3R1")
## Executing this script
runEx("C3R1", echo = TRUE)
